==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebFilteringExpressionDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebFilteringExpressionDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringExpressionDescription, _super);
    function WebFilteringExpressionDescription() {
        var _this = _super.call(this) || this;
        _this.n = null;
        _this.f = null;
        _this.k = null;
        _this.i = false;
        return _this;
    }
    WebFilteringExpressionDescription.prototype.get_type = function () {
        return "WebFilteringExpression";
    };
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "fieldName", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.e("FieldName");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "condition", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Condition");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "searchVal", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e("SearchVal");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "ignoreCase", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.e("IgnoreCase");
        },
        enumerable: true,
        configurable: true
    });
    WebFilteringExpressionDescription.$t = markType(WebFilteringExpressionDescription, 'WebFilteringExpressionDescription', Description.$);
    WebFilteringExpressionDescription.__marshalByValue = true;
    WebFilteringExpressionDescription.__marshalByValueAlias = "FilteringExpression";
    return WebFilteringExpressionDescription;
}(Description));
export { WebFilteringExpressionDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebFilteringExpressionDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescription } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebFilteringExpressionDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringExpressionDescription, _super);
    function WebFilteringExpressionDescription() {
        var _this = _super.call(this) || this;
        _this.t = null;
        _this.k = null;
        _this.s = null;
        _this.p = null;
        _this.i = null;
        _this.n = false;
        return _this;
    }
    WebFilteringExpressionDescription.prototype.get_type = function () {
        return "WebFilteringExpression";
    };
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "fieldName", {
        get: function () {
            return this.t;
        },
        set: function (a) {
            this.t = a;
            this.g("FieldName");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "condition", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.g("Condition");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "conditionName", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.g("ConditionName");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "searchVal", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.g("SearchVal");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "searchTree", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("SearchTree");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionDescription.prototype, "ignoreCase", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.g("IgnoreCase");
        },
        enumerable: false,
        configurable: true
    });
    WebFilteringExpressionDescription.$t = markType(WebFilteringExpressionDescription, 'WebFilteringExpressionDescription', WebFilteringExpressionsTreeOrFilteringExpressionDescription.$);
    WebFilteringExpressionDescription.__marshalByValue = true;
    WebFilteringExpressionDescription.__marshalByValueAlias = "FilteringExpression";
    return WebFilteringExpressionDescription;
}(WebFilteringExpressionsTreeOrFilteringExpressionDescription));
export { WebFilteringExpressionDescription };
